﻿using System;
using System.Collections.Generic;
using TaleWorlds.Core;
using TaleWorlds.Engine;
using TaleWorlds.Library;
using TaleWorlds.MountAndBlade;

namespace gunmod
{
	// Token: 0x0200000D RID: 13
	internal static class gunhelper
	{
		// Token: 0x06000098 RID: 152 RVA: 0x000069E8 File Offset: 0x00004BE8
		public static void show(this List<ParticleSystem> particles)
		{
			foreach (ParticleSystem particleSystem in particles)
			{
				particleSystem.SetEnable(true);
			}
		}

		// Token: 0x06000099 RID: 153 RVA: 0x00006A34 File Offset: 0x00004C34
		public static void hide(this List<ParticleSystem> particles)
		{
			foreach (ParticleSystem particleSystem in particles)
			{
				particleSystem.SetEnable(false);
			}
		}

		// Token: 0x0600009A RID: 154 RVA: 0x00006A80 File Offset: 0x00004C80
		public static GunType getGunType(this MissionWeapon weapon)
		{
			if (!weapon.IsEmpty && weapon.Item != null && weapon.Item.StringId != null)
			{
				string stringId = weapon.Item.StringId;
				if (stringId.Contains("dv_gun"))
				{
					return GunType.步枪;
				}
				if (stringId.Contains("dv_3H_gun"))
				{
					return GunType.三眼神铳;
				}
				if (stringId.Contains("dv_simple_gun"))
				{
					return GunType.简易火铳;
				}
				if (stringId.Contains("dv_2B_gun"))
				{
					return GunType.双管步枪;
				}
			}
			return GunType.NULL;
		}

		// Token: 0x0600009B RID: 155 RVA: 0x00006B18 File Offset: 0x00004D18
		public static string chineseString(this FormationClass formation)
		{
			string result = "";
			switch ((int)formation)
			{
			case 0:
				result = "步兵";
				break;
			case 1:
				result = "弓弩手";
				break;
			case 2:
				result = "骑兵";
				break;
			case 3:
				result = "骑射手";
				break;
			case 4:
				result = "火枪手";
				break;
			case 5:
				result = "重步兵";
				break;
			case 6:
				result = "轻骑兵";
				break;
			case 7:
				result = "重骑兵";
				break;
			case 8:
				result = "将领";
				break;
			case 9:
				result = "侍卫";
				break;
			case 10:
				result = "全体";
				break;
			}
			return result;
		}

		// Token: 0x0600009C RID: 156 RVA: 0x00006BB8 File Offset: 0x00004DB8
		public static List<MissionWeapon> getBows(this Agent agent)
		{
			List<MissionWeapon> list = new List<MissionWeapon>();
			if (agent != null && agent.Equipment != null)
			{
				for (int i = 0; i < 5; i++)
				{
					if (agent.Equipment[i].isBowOrCrossbow())
					{
						list.Add(agent.Equipment[i]);
					}
				}
			}
			return list;
		}

		// Token: 0x0600009D RID: 157 RVA: 0x00006C08 File Offset: 0x00004E08
		public static bool hasRoloaded(this MissionWeapon weapon)
		{
			return weapon.ReloadPhase == 2;
		}

		// Token: 0x0600009E RID: 158 RVA: 0x00006C14 File Offset: 0x00004E14
		public static bool hasAnyRoloaded(this List<MissionWeapon> weapons)
		{
			using (List<MissionWeapon>.Enumerator enumerator = weapons.GetEnumerator())
			{
				while (enumerator.MoveNext())
				{
					if (enumerator.Current.hasRoloaded())
					{
						return true;
					}
				}
			}
			return false;
		}

		// Token: 0x0600009F RID: 159 RVA: 0x00006C68 File Offset: 0x00004E68
		public static bool isReadyToShoot(this Agent agent)
		{
			return agent.getBows().hasAnyRoloaded();
		}

		// Token: 0x060000A0 RID: 160 RVA: 0x00006C75 File Offset: 0x00004E75
		public static bool isReadyToAttack(this Agent agent)
		{
			return agent.isReadyToShoot() || agent.getBows().Count == 0;
		}

		// Token: 0x060000A1 RID: 161 RVA: 0x00006C8F File Offset: 0x00004E8F
		public static bool notShootYet(this Agent agent)
		{
			return agent.isReadyToShoot() && agent.getBows().Count > 0;
		}

		// Token: 0x060000A2 RID: 162 RVA: 0x00006CAC File Offset: 0x00004EAC
		public static bool notShootYet(this List<Agent> agents)
		{
			w.Write("notShootYet_start");
			using (List<Agent>.Enumerator enumerator = agents.GetEnumerator())
			{
				while (enumerator.MoveNext())
				{
					if (enumerator.Current.notShootYet())
					{
						w.Write("notShootYet_return");
						return true;
					}
				}
			}
			w.Write("notShootYet_return");
			return false;
		}

		// Token: 0x060000A3 RID: 163 RVA: 0x00006D20 File Offset: 0x00004F20
		public static bool isUsingBow(this Agent agent)
		{
			return agent.getBows().Count > 0;
		}

		// Token: 0x060000A4 RID: 164 RVA: 0x00006D30 File Offset: 0x00004F30
		public static bool isReadyToShoot(this List<Agent> agents)
		{
			w.Write("isReadyToShoot_start");
			foreach (Agent agent in agents)
			{
				if (agent != null && agent.IsActive() && !agent.isReadyToShoot())
				{
					w.Write("isReadyToShoot_return");
					return false;
				}
			}
			w.Write("isReadyToShoot_return");
			return true;
		}

		// Token: 0x060000A5 RID: 165 RVA: 0x00006DB0 File Offset: 0x00004FB0
		public static bool isAlmostReadyToShoot(this List<Agent> agents, double rate)
		{
			if (rate > 1.0)
			{
				rate = 1.0;
			}
			double num = 0.0;
			double num2 = 0.0;
			foreach (Agent agent in agents)
			{
				if (agent != null && agent.IsActive() && agent.isUsingBow())
				{
					num += 1.0;
					if (agent.isReadyToShoot())
					{
						num2 += 1.0;
					}
				}
			}
			return num2 / num > rate;
		}

		// Token: 0x060000A6 RID: 166 RVA: 0x00006E5C File Offset: 0x0000505C
		public static bool isReadyToAttack(this List<Agent> agents)
		{
			foreach (Agent agent in agents)
			{
				if (agent != null && agent.IsActive() && !agent.isReadyToAttack())
				{
					return false;
				}
			}
			return true;
		}

		// Token: 0x060000A7 RID: 167 RVA: 0x00006EC0 File Offset: 0x000050C0
		public static void setpos(this Agent agent, Vec2 pos, Vec3 di)
		{
			w.Write("setpos_start");
			if (agent != null && agent.IsActive())
			{
				agent.SetTargetPositionAndDirection(pos, di);
				agent.Controller =(Agent.ControllerType) 1;
			}
			w.Write("setpos_end");
		}

		// Token: 0x060000A8 RID: 168 RVA: 0x00006EF0 File Offset: 0x000050F0
		public static void setpos(this List<Agent> agents, Vec2 pos, Vec2 d)
		{
			w.Write("setpos(list)_start");
			int count = agents.Count;
			Vec2 vec = pos - d * 0.5f;
			Vector2 vector = d.dv2().row(-90.0);
			for (int i = 0; i < agents.Count; i++)
			{
				agents[i].setpos(vec, new Vec3((float)vector.X, (float)vector.Y, 0f, -1f));
				vec += d;
			}
			w.Write("setpos(list)_end");
		}

		// Token: 0x060000A9 RID: 169 RVA: 0x00006F84 File Offset: 0x00005184
		public static void sayHoldfire(this Agent agent)
		{
			if (agent != null & agent.IsActive())
			{
				agent.MakeVoice(new SkinVoiceManager.SkinVoiceType("HoldFire"), 0);
			}
		}

		// Token: 0x060000AA RID: 170 RVA: 0x00006FA4 File Offset: 0x000051A4
		public static void sayFireAtWill(this Agent agent)
		{
			if (agent != null & agent.IsActive())
			{
				agent.MakeVoice(new SkinVoiceManager.SkinVoiceType("FireAtWill"), 0);
			}
		}

		// Token: 0x060000AB RID: 171 RVA: 0x00006FC4 File Offset: 0x000051C4
		public static bool isHoldingFire(this Agent agent)
		{
			return ((int)agent.GetAgentFlags() & 8) != 8;
		}

		// Token: 0x060000AC RID: 172 RVA: 0x00006FD4 File Offset: 0x000051D4
		public static void HoldFire(this Agent agent)
		{
			w.Write("HoldFire_start");
			if (agent != null && agent.IsActive())
			{
				agent.SetAgentFlags((AgentFlag)(((int)agent.GetAgentFlags()) & -9));
			}
			w.Write("HoldFire_end");
		}

		// Token: 0x060000AD RID: 173 RVA: 0x00007004 File Offset: 0x00005204
		public static void HoldFire(this List<Agent> agents)
		{
			w.Write("HoldFire(list)_start");
			foreach (Agent agent in agents)
			{
				agent.HoldFire();
			}
			w.Write("HoldFire(list)_end");
		}

		// Token: 0x060000AE RID: 174 RVA: 0x00007064 File Offset: 0x00005264
		public static void FireAtWill(this Agent agent)
		{
			w.Write("FireAtWill_start");
			if (agent != null && agent.IsActive())
			{
				agent.SetAgentFlags((AgentFlag)((int)agent.GetAgentFlags() | 8));
			}
			w.Write("FireAtWill_end");
		}

		// Token: 0x060000AF RID: 175 RVA: 0x00007094 File Offset: 0x00005294
		public static void FireAtWill(this List<Agent> agents)
		{
			w.Write("FireAtWill(list)_start");
			foreach (Agent agent in agents)
			{
				agent.FireAtWill();
			}
			w.Write("FireAtWill(list)_end");
		}

		// Token: 0x060000B0 RID: 176 RVA: 0x000070F4 File Offset: 0x000052F4
		public static bool isCrossbow(this MissionWeapon weapon)
		{
			return !weapon.IsEmpty && weapon.CurrentUsageItem != null && (int)weapon.CurrentUsageItem.WeaponClass == 16;
		}

		// Token: 0x060000B1 RID: 177 RVA: 0x0000711A File Offset: 0x0000531A
		public static bool isBowOrCrossbow(this MissionWeapon weapon)
		{
			return !weapon.IsEmpty && weapon.CurrentUsageItem != null && ((int)weapon.CurrentUsageItem.WeaponClass == 16 || (int)weapon.CurrentUsageItem.WeaponClass == 15);
		}

		// Token: 0x060000B2 RID: 178 RVA: 0x00007152 File Offset: 0x00005352
		public static bool IsAgentUnderPlayer(this Agent agent)
		{
			return agent != null && agent.IsHuman && agent.Origin.IsUnderPlayersCommand;
		}
	}
}
